summaryrefslogtreecommitdiff
path: root/gpsd.h
diff options
context:
space:
mode:
authorGary E. Miller <gem@rellim.com>2019-01-24 16:24:15 -0800
committerGary E. Miller <gem@rellim.com>2019-01-24 16:24:15 -0800
commit07e43d77c00b4620ab326dbc5227bf8b7e8aab3a (patch)
tree0eb9b9abb493c43e5727a037363858e9209658e0 /gpsd.h
parentaa40e12a01de0d558e85254f5467fd546185ff3c (diff)
downloadgpsd-07e43d77c00b4620ab326dbc5227bf8b7e8aab3a.tar.gz
gpsd.h: Make cfg_step and cfg_stage part of session.
The SiRFstar step type init will get used on other drivers that now have similar buffer stuffing issues.
Diffstat (limited to 'gpsd.h')
-rw-r--r--gpsd.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/gpsd.h b/gpsd.h
index c2f19b29..cef53a6f 100644
--- a/gpsd.h
+++ b/gpsd.h
@@ -53,6 +53,7 @@ extern "C" {
* 3.13 gnssid:svid added to SAT
* time added to ATT
* 3.14 Added RAW message class.
+ * Add cfg_stage and cfg_step, for initialization
*/
/* Keep in sync with api_major_version and api_minor gps/__init__.py */
#define GPSD_PROTO_MAJOR_VERSION 3 /* bump on incompatible changes */
@@ -490,8 +491,10 @@ struct gps_device_t {
/* session object, encapsulates all global state */
struct gps_data_t gpsdata;
const struct gps_type_t *device_type;
- unsigned int driver_index; /* numeric index of current driver */
- unsigned int drivers_identified; /* bitmask; what drivers have we seen? */
+ unsigned int driver_index; /* numeric index of current driver */
+ unsigned int drivers_identified; /* bitmask; what drivers have we seen? */
+ unsigned int cfg_stage; /* configuration stage counter */
+ unsigned int cfg_step; /* configuration step counter */
#ifdef RECONFIGURE_ENABLE
const struct gps_type_t *last_controller;
#endif /* RECONFIGURE_ENABLE */
@@ -617,7 +620,6 @@ struct gps_device_t {
#ifdef SIRF_ENABLE
struct {
unsigned int need_ack; /* if NZ we're awaiting ACK */
- unsigned int cfg_stage; /* configuration stage counter */
unsigned int driverstate; /* for private use */
#define SIRF_LT_231 0x01 /* SiRF at firmware rev < 231 */
#define SIRF_EQ_231 0x02 /* SiRF at firmware rev == 231 */